@@ -6,8 +6,6 @@ use std::{
 
 use crate::utils::{domain_or_default, ToHostname};
 
-pub const HOSTS_DIR: &str = "testdata/hosts-files";
-
 #[test]
 fn test_parse_member_name() {
     use crate::utils::parse_member_name;
@@ -25,7 +23,7 @@ fn test_parse_member_name() {
 
         assert_eq!(parse_member_name(None, domain_name.clone()), None);
 
-        for name in vec!["islay", "ALL-CAPS", "Capitalized", "with.dots"] {
+        for name in ["islay", "ALL-CAPS", "Capitalized", "with.dots"] {
             assert_eq!(
                 parse_member_name(Some(name.to_string()), domain_name.clone()),
                 Some(name.to_fqdn(domain_name.clone()).unwrap()),
@@ -34,7 +32,7 @@ fn test_parse_member_name() {
             );
         }
 
-        for bad_name in vec![".", "!", "arghle."] {
+        for bad_name in [".", "!", "arghle."] {
             assert_eq!(
                 parse_member_name(Some(bad_name.to_string()), domain_name.clone()),
                 None,
@@ -43,7 +41,7 @@ fn test_parse_member_name() {
             );
         }
 
-        for (orig, translated) in vec![("Erik's laptop", "eriks-laptop"), ("!foo", "foo")] {
+        for (orig, translated) in [("Erik's laptop", "eriks-laptop"), ("!foo", "foo")] {
             assert_eq!(
                 parse_member_name(Some(orig.to_string()), domain_name.clone()),
                 Some(translated.to_fqdn(domain_name.clone()).unwrap()),
@@ -95,7 +93,7 @@ fn test_domain_or_default() {
         Name::from_str("zerotier.tld").unwrap()
     );
 
-    for bad in vec!["bad.", "~", "!", ".", ""] {
+    for bad in ["bad.", "~", "!", ".", ""] {
         assert!(domain_or_default(Some(bad)).is_err(), "{}", bad);
     }
 }
@@ -147,6 +145,7 @@ fn test_supervise_systemd_green() {
                 hosts_file: Some(PathBuf::from("/etc/hosts")),
                 wildcard_names: true,
                 distro: None,
+                ..Default::default()
             },
         ),
     ];
@@ -166,11 +165,8 @@ fn test_supervise_systemd_green() {
         if !write {
             let path = path.canonicalize();
 
-            assert!(path.is_ok(), "{}", name);
             let expected = std::fs::read_to_string(path.unwrap());
-            assert!(expected.is_ok(), "{}", name);
             let testing = props.supervise_template();
-            assert!(testing.is_ok(), "{}", name);
 
             assert_eq!(testing.unwrap(), expected.unwrap(), "{}", name);
         } else {
@@ -296,7 +292,7 @@ fn test_parse_hosts() {
 
     let domain = &Name::from_str("zombocom").unwrap();
 
-    for path in std::fs::read_dir(HOSTS_DIR)
+    for path in std::fs::read_dir(crate::utils::TEST_HOSTS_DIR)
         .unwrap()
         .into_iter()
         .map(|p| p.unwrap())
@@ -363,11 +359,7 @@ fn test_parse_hosts_duplicate() {
     assert!(result.is_some());
     let result = result.unwrap();
 
-    assert!(result.contains(
-        &Name::from_str("hostname1")
-            .unwrap()
-            .append_domain(&domain.clone())
-    ));
+    assert!(result.contains(&Name::from_str("hostname1").unwrap().append_domain(&domain)));
     assert!(result.contains(
         &Name::from_str("hostname2.corp")
             .unwrap()
