@@ -1,58 +1,63 @@
-use std::{net::IpAddr, path::Path, str::FromStr};
+use std::{net::IpAddr, path::Path, str::FromStr, sync::Once};
 
 use ipnetwork::IpNetwork;
 use log::warn;
 use regex::Regex;
-use tokio::runtime::Runtime;
 use trust_dns_resolver::IntoName;
 use trust_dns_server::client::rr::Name;
 use zerotier_central_api::apis::configuration::Configuration;
 
 use anyhow::anyhow;
 
+// collections of test hosts files
+pub const TEST_HOSTS_DIR: &str = "testdata/hosts-files";
 // default domain parameter. FIXME change to home.arpa.
-pub(crate) const DOMAIN_NAME: &str = "domain.";
+pub const DOMAIN_NAME: &str = "home.arpa.";
 // zeronsd version calculated from Cargo.toml
-pub(crate) const VERSION_STRING: &str = env!("CARGO_PKG_VERSION");
+pub const VERSION_STRING: &str = env!("CARGO_PKG_VERSION");
 
 // this really needs to be replaced with lazy_static! magic
 fn version() -> String {
     "zeronsd ".to_string() + VERSION_STRING
 }
 
-// this provides the production configuration for talking to central through the openapi libraries.
-pub(crate) fn central_config(token: String) -> Configuration {
-    let mut config = Configuration::default();
-    config.user_agent = Some(version());
-    config.bearer_access_token = Some(token);
+static LOGGER: Once = Once::new();
 
-    if let Ok(instance) = std::env::var("ZEROTIER_CENTRAL_INSTANCE") {
-        config.base_path = instance
-    }
-
-    return config;
+// initializes a logger
+pub fn init_logger() {
+    LOGGER.call_once(|| {
+        env_logger::builder()
+            .filter_level(log::LevelFilter::Error)
+            .parse_default_env()
+            .parse_env("ZERONSD_LOG")
+            .init();
+    })
 }
 
-// create a tokio runtime. We don't use the macros (they are hard to use) so this is the closest
-// we'll get to being able to get a runtime easily.
-pub(crate) fn init_runtime() -> Runtime {
-    tokio::runtime::Builder::new_multi_thread()
-        .enable_all()
-        .worker_threads(num_cpus::get())
-        .thread_name("zeronsd")
-        .build()
-        .expect("failed to initialize tokio")
+// this provides the production configuration for talking to central through the openapi libraries.
+pub fn central_config(token: String) -> Configuration {
+    let mut config = Configuration {
+        user_agent: Some(version()),
+        bearer_access_token: Some(token),
+        ..Default::default()
+    };
+
+    if let Ok(instance) = std::env::var("ZEROTIER_CENTRAL_INSTANCE") {
+        config.base_path = instance;
+    }
+
+    config
 }
 
 // extracts the ip from the CIDR. 10.0.0.1/32 becomes 10.0.0.1
-pub(crate) fn parse_ip_from_cidr(ip_with_cidr: String) -> IpAddr {
+pub fn parse_ip_from_cidr(ip_with_cidr: String) -> IpAddr {
     IpNetwork::from_str(&ip_with_cidr)
         .expect("Could not parse IP from CIDR")
         .ip()
 }
 
 // load and prepare the central API token
-pub(crate) fn central_token(arg: Option<&Path>) -> Result<String, anyhow::Error> {
+pub fn central_token(arg: Option<&Path>) -> Result<String, anyhow::Error> {
     if let Some(path) = arg {
         return Ok(std::fs::read_to_string(path)
             .expect("Could not load token file")
@@ -70,7 +75,7 @@ pub(crate) fn central_token(arg: Option<&Path>) -> Result<String, anyhow::Error>
 }
 
 // determine the path of the authtoken.secret
-pub(crate) fn authtoken_path(arg: Option<&Path>) -> &Path {
+pub fn authtoken_path(arg: Option<&Path>) -> &Path {
     if let Some(arg) = arg {
         return arg;
     }
@@ -87,7 +92,7 @@ pub(crate) fn authtoken_path(arg: Option<&Path>) -> &Path {
 }
 
 // use the default tld if none is supplied.
-pub(crate) fn domain_or_default(tld: Option<&str>) -> Result<Name, anyhow::Error> {
+pub fn domain_or_default(tld: Option<&str>) -> Result<Name, anyhow::Error> {
     if let Some(tld) = tld {
         if tld.len() > 0 {
             return Ok(Name::from_str(&format!("{}.", tld))?);
@@ -100,7 +105,7 @@ pub(crate) fn domain_or_default(tld: Option<&str>) -> Result<Name, anyhow::Error
 }
 
 // parse_member_name ensures member names are DNS compliant
-pub(crate) fn parse_member_name(name: Option<String>, domain_name: Name) -> Option<Name> {
+pub fn parse_member_name(name: Option<String>, domain_name: Name) -> Option<Name> {
     if let Some(name) = name {
         let name = name.trim();
         if name.len() > 0 {
@@ -119,7 +124,7 @@ pub(crate) fn parse_member_name(name: Option<String>, domain_name: Name) -> Opti
 
 // get_listen_ips returns the IPs that the network is providing to the instance running zeronsd.
 // 4193 and 6plane are handled up the stack.
-pub(crate) async fn get_listen_ips(
+pub async fn get_listen_ips(
     authtoken_path: &Path,
     network_id: &str,
 ) -> Result<Vec<String>, anyhow::Error> {
@@ -159,31 +164,28 @@ pub(crate) async fn get_listen_ips(
 }
 
 // update_central_dns pushes the search records
-pub(crate) fn update_central_dns(
-    runtime: &mut Runtime,
+pub async fn update_central_dns(
     domain_name: Name,
     ips: Vec<String>,
     config: Configuration,
     network: String,
 ) -> Result<(), anyhow::Error> {
-    let mut zt_network = runtime.block_on(
-        zerotier_central_api::apis::network_api::get_network_by_id(&config, &network),
-    )?;
+    let mut zt_network =
+        zerotier_central_api::apis::network_api::get_network_by_id(&config, &network).await?;
 
-    let mut domain_name = domain_name.clone();
+    let mut domain_name = domain_name;
     domain_name.set_fqdn(false);
 
-    let dns = Some(Box::new(zerotier_central_api::models::NetworkConfigDns {
+    let dns = Some(zerotier_central_api::models::Dns {
         domain: Some(domain_name.to_string()),
         servers: Some(ips),
-    }));
+    });
 
     if let Some(mut zt_network_config) = zt_network.config.to_owned() {
         zt_network_config.dns = dns;
         zt_network.config = Some(zt_network_config);
-        runtime.block_on(zerotier_central_api::apis::network_api::update_network(
-            &config, &network, zt_network,
-        ))?;
+        zerotier_central_api::apis::network_api::update_network(&config, &network, zt_network)
+            .await?;
     }
 
     Ok(())
@@ -198,14 +200,14 @@ fn translation_table() -> Vec<(Regex, &'static str)> {
     ]
 }
 
-pub(crate) trait ToHostname {
+pub trait ToHostname {
     fn to_hostname(self) -> Result<Name, anyhow::Error>;
     fn to_fqdn(self, domain: Name) -> Result<Name, anyhow::Error>;
 }
 
 impl ToHostname for &str {
     fn to_hostname(self) -> Result<Name, anyhow::Error> {
-        self.clone().to_string().to_hostname()
+        self.to_string().to_hostname()
     }
 
     fn to_fqdn(self, domain: Name) -> Result<Name, anyhow::Error> {
@@ -216,7 +218,7 @@ impl ToHostname for &str {
 impl ToHostname for String {
     // to_hostname turns member names into trust-dns compatible dns names.
     fn to_hostname(self) -> Result<Name, anyhow::Error> {
-        let mut s = self.clone().trim().to_string();
+        let mut s = self.trim().to_string();
         for (regex, replacement) in translation_table() {
             s = regex.replace_all(&s, replacement).to_string();
         }
